<?php
session_start();
require '../config.php';

// Check if the school admin is already logged in, if yes then redirect him to dashboard
if(isset($_SESSION["school_in"]) && $_SESSION["school_in"] === true){
    echo "<meta http-equiv='refresh' content='0;url=https://mysmartschool.site/0/super/sauth/'>";
    exit;
}

// Define variables and initialize with empty values
$email = $password = "";
$email_err = $password_err = "";
 
// Processing form data when form is submitted
if($_SERVER["REQUEST_METHOD"] == "POST"){
 
    // Check if email is empty
    if(empty(trim($_POST["email"]))){
        $email_err = "Please enter your email.";
    } else{
        $email = trim($_POST["email"]);
    }
    
    // Check if password is empty
    if(empty(trim($_POST["password"]))){
        $password_err = "Please enter your password.";
    } else{
        $password = trim($_POST["password"]);
    }
    
    // Validate credentials
    if(empty($email_err) && empty($password_err)){
        // Prepare a select statement
        $sql = "SELECT school_id, firstname, lastname, email, password FROM school_admins WHERE email = ?";
        
        if($stmt = mysqli_prepare($conn, $sql)){
            // Bind variables to the prepared statement as parameters
            mysqli_stmt_bind_param($stmt, "s", $param_email);
            
            // Set parameters
            $param_email = $email;
            
            // Attempt to execute the prepared statement
            if(mysqli_stmt_execute($stmt)){
                // Store result
                mysqli_stmt_store_result($stmt);
                
                // Check if email exists, if yes then verify password
                if(mysqli_stmt_num_rows($stmt) == 1){                    
                    // Bind result variables
                    mysqli_stmt_bind_result($stmt, $school_id, $firstname, $lastname, $email, $hashed_password);
                    if(mysqli_stmt_fetch($stmt)){
                        if(password_verify($password, $hashed_password)){
                            // Password is correct, so start a new session
                            session_start();
                            
                            // Store data in session variables
                            $_SESSION["school_in"] = true;
                            $_SESSION["school_id"] = $school_id;
                            $_SESSION["firstname"] = $firstname;
                            $_SESSION["lastname"] = $lastname;
                            $_SESSION["email"] = $email;
                            
                            //check school status then redirect appropriately
                            $stmt = $conn->PREPARE("SELECT `school_status` FROM `schools` WHERE `school_id` = ?");
                            $stmt->BIND_PARAM("s",$school_id);
                            $stmt->EXECUTE();
                            $result = $stmt->GET_RESULT();
                            while ($row = $result->fetch_assoc()){
                                $status = $row['school_status'];
                            }
                            if ($status==0){
                                echo "<meta http-equiv='refresh' content='0;url=https://mysmartschool.site/0/super/sauth/inactive.php'>";
                            }elseif($status==1){
                                // Redirect user to dashboard
                                echo "<meta http-equiv='refresh' content='0;url=https://mysmartschool.site/0/super/sauth/'>";
                            }else{
                                echo "<meta http-equiv='refresh' content='0;url=https://mysmartschool.site/0/super/sauth/404.php'>";
                            }
                            
                        } else{
                            // Display an error message if password is not valid
                            $password_err = "The password you entered was not valid.";
                        }
                    }
                } else{
                    // Display an error message if email doesn't exist
                    $email_err = "No account found with that email.";
                }
            } else{
                echo "Oops! Something went wrong. Please try again later.";
            }

            // Close statement
            mysqli_stmt_close($stmt);
        }
    }
    
    // Close connection
    mysqli_close($conn);
}

?>


<!DOCTYPE html>
<html lang="en"
      dir="ltr">

    <head>
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible"
              content="IE=edge">
        <meta name="viewport"
              content="width=device-width, initial-scale=1, shrink-to-fit=no">
        <title>Login as School Admin</title>


        <link href="https://fonts.googleapis.com/css?family=Lato:400,700%7CRoboto:400,500%7CExo+2:600&display=swap"
              rel="stylesheet">

        <!-- Preloader -->
        <link type="text/css"
              href="../public/vendor/spinkit.css"
              rel="stylesheet">

        <!-- Perfect Scrollbar -->
        <link type="text/css"
              href="../public/vendor/perfect-scrollbar.css"
              rel="stylesheet">

        <!-- Material Design Icons -->
        <link type="text/css"
              href="../public/css/material-icons.css"
              rel="stylesheet">

        <!-- Font Awesome Icons -->
        <link type="text/css"
              href="../public/css/fontawesome.css"
              rel="stylesheet">

        <!-- Preloader -->
        <link type="text/css"
              href="../public/css/preloader.css"
              rel="stylesheet">

        <!-- App CSS -->
        <link type="text/css"
              href="../public/css/app.css"
              rel="stylesheet">

    </head>
    
    <style>
        .field-icon {
        float: right;
        margin-right: 8px;
        margin-top: -23px;
        position: relative;
        z-index: 2;
        cursor:pointer;
        }
        
        .container{
        padding-top:50px;
        margin: auto;
        }
    </style>

    <body class="layout-default layout-login-centered-boxed">

        <div class="layout-login-centered-boxed__form card">
            <div class="d-flex flex-column justify-content-center align-items-center mt-2 mb-5 navbar-light">
                <a href="index.html"
                   class="navbar-brand flex-column mb-2 align-items-center mr-0"
                   style="min-width: 0">

                    <span class="avatar avatar-sm navbar-brand-icon mr-0">

                        <span class="avatar-title rounded bg-primary"><img src="../public/images/illustration/student/128/white.svg"
                                 alt="logo"
                                 class="img-fluid" /></span>

                    </span>

                    SmartSchool
                </a>
                <p class="m-0">You are welcome to the <strong>school admin</strong> portal! </p>
            </div>

            <form action="<?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>" Method="POST" >
                <div class="form-group">
                    <label class="text-label"
                           for="email_2">Email Address:</label>
                    <div class="input-group input-group-merge">
                        <input name="email"
                               id="email_2"
                               type="email"
                               required=""
                               class="form-control form-control-prepended"
                               placeholder="admin@example.com">
                        <div class="input-group-prepend">
                            <div class="input-group-text">
                                <span class="far fa-envelope"></span>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="form-group">
                    <label class="text-label"
                           for="password-field">Password:</label>
                    <div class="input-group input-group-merge">
                        <input id="password-field"
                               name="password"
                               type="password"
                               required=""
                               class="form-control form-control-prepended"
                               placeholder="Enter your password">
                        <div class="input-group-prepend">
                            <div class="input-group-text">
                                <span class="fa fa-key"></span>
                            </div>
                        </div>
                    </div>
                    <span toggle="#password-field" class="fa fa-sm fa-eye field-icon toggle-password"></span>
                </div>
                <div class="form-group">
                    <button class="btn btn-block btn-primary"
                            type="submit">Login</button>
                </div>
                <?php if($password_err){echo "<div class='alert alert-danger'>$password_err</div>"; } ?>
                <?php if($email_err){echo "<div class='alert alert-danger'>$email_err</div>"; } ?>
            </form>
        </div>

        <!-- jQuery -->
        <script src="../public/vendor/jquery.min.js"></script>
        <script>
            $(".toggle-password").click(function() {
               $(this).toggleClass("fa-eye fa-eye-slash");
               var input = $($(this).attr("toggle"));
               if (input.attr("type") == "password") {
                 input.attr("type", "text");
               } else {
                 input.attr("type", "password");
               }
            });
        </script>

        <!-- Bootstrap -->
        <script src="../public/vendor/popper.min.js"></script>
        <script src="../public/vendor/bootstrap.min.js"></script>

        <!-- Perfect Scrollbar -->
        <script src="../public/vendor/perfect-scrollbar.min.js"></script>

        <!-- DOM Factory -->
        <script src="../public/vendor/dom-factory.js"></script>

        <!-- MDK -->
        <script src="../public/vendor/material-design-kit.js"></script>

        <!-- App JS -->
        <script src="../public/js/app.js"></script>

        <!-- Preloader -->
        <script src="../public/js/preloader.js"></script>

    </body>

</html>